@@ -1,3 +1,9 @@
+/*
+ * SPDX-FileCopyrightText: 2014-2015 David Rosca <nowrep@gmail.com>
+ *
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+ */
+
 #ifndef DEVICETEST_H
 #define DEVICETEST_H
 
@@ -16,7 +22,7 @@ class DeviceTest : public QObject
     Q_OBJECT
 
 public:
-    explicit DeviceTest(bool fakeBluezRun = false);
+    explicit DeviceTest();
 
 private Q_SLOTS:
     void initTestCase();
@@ -37,9 +43,11 @@ private:
         org::freedesktop::DBus::Properties *dbusProperties;
     };
 
+    QString deviceIcon(org::bluez::Device1 *device) const;
+    qint16 deviceRssi(org::bluez::Device1 *device) const;
+
     BluezQt::Manager *m_manager;
     QList<DeviceUnit> m_units;
-    bool m_fakeBluezRun;
 };
 
 #endif // DEVICETEST_H
