@@ -1,3 +1,9 @@
+/*
+ * SPDX-FileCopyrightText: 2014-2015 David Rosca <nowrep@gmail.com>
+ *
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+ */
+
 #ifndef OBJECTMANAGER_H
 #define OBJECTMANAGER_H
 
@@ -19,7 +25,7 @@ class ObjectManager : public QDBusAbstractAdaptor
     Q_CLASSINFO("D-Bus Interface", "org.freedesktop.DBus.ObjectManager")
 
 public:
-    explicit ObjectManager(QObject *parent = Q_NULLPTR);
+    explicit ObjectManager(QObject *parent = nullptr);
     ~ObjectManager();
 
     void addObject(Object *object);
