@@ -1,6 +1,13 @@
+/*
+ * SPDX-FileCopyrightText: 2014-2015 David Rosca <nowrep@gmail.com>
+ *
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+ */
+
 #ifndef TESTINTERFACE_H
 #define TESTINTERFACE_H
 
+#include <QDBusMessage>
 #include <QDBusAbstractAdaptor>
 
 class FakeBluez;
@@ -13,17 +20,15 @@ class TestInterface : public QDBusAbstractAdaptor
 public:
     explicit TestInterface(FakeBluez *parent);
 
-    void emitActionFinished();
-
 public Q_SLOTS:
     void runTest(const QString &testName);
-    void runAction(const QString &object, const QString &actionName, const QVariantMap &properties);
+    void runAction(const QString &object, const QString &actionName, const QVariantMap &properties, const QDBusMessage &msg);
 
-Q_SIGNALS:
-    void actionFinished();
+    void emitActionFinished();
 
 private:
     FakeBluez *m_fakeBluez;
+    QDBusMessage m_msg;
 };
 
 #endif // TESTINTERFACE_H
