@@ -1,3 +1,9 @@
+/*
+ * SPDX-FileCopyrightText: 2014-2015 David Rosca <nowrep@gmail.com>
+ *
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+ */
+
 #ifndef OBEXMANAGERTEST_H
 #define OBEXMANAGERTEST_H
 
@@ -9,7 +15,7 @@ class ObexManagerTest : public QObject
 
 private Q_SLOTS:
     void initTestCase();
-    void cleanupTestCase();
+    void cleanup();
 
     void obexNotRunningTest();
     void obexNotExportingInterfacesTest();
