@@ -1,31 +1,18 @@
 /*
  * BluezQt - Asynchronous Bluez wrapper library
  *
- * Copyright (C) 2014 David Rosca <nowrep@gmail.com>
+ * SPDX-FileCopyrightText: 2014-2015 David Rosca <nowrep@gmail.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library. If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #include "obexmanager_p.h"
 #include "obexmanager.h"
+#include "obexsession.h"
+#include "obexsession_p.h"
 #include "debug.h"
 #include "utils.h"
 
-#include "dbusobjectmanager.h"
 
 #include <QDBusServiceWatcher>
 
@@ -37,9 +24,9 @@ typedef org::freedesktop::DBus::ObjectManager DBusObjectManager;
 ObexManagerPrivate::ObexManagerPrivate(ObexManager *q)
     : QObject(q)
     , q(q)
-    , m_obexClient(0)
-    , m_obexAgentManager(0)
-    , m_dbusObjectManager(0)
+    , m_obexClient(nullptr)
+    , m_obexAgentManager(nullptr)
+    , m_dbusObjectManager(nullptr)
     , m_initialized(false)
     , m_obexRunning(false)
     , m_loaded(false)
@@ -47,15 +34,8 @@ ObexManagerPrivate::ObexManagerPrivate(ObexManager *q)
     qDBusRegisterMetaType<DBusManagerStruct>();
     qDBusRegisterMetaType<QVariantMapMap>();
 
-    m_timer = new QTimer(this);
-    m_timer->setSingleShot(true);
-    m_timer->setInterval(500);
-    connect(m_timer, &QTimer::timeout, this, &ObexManagerPrivate::load);
-}
-
-ObexManagerPrivate::~ObexManagerPrivate()
-{
-    clear();
+    m_timer.setSingleShot(true);
+    connect(&m_timer, &QTimer::timeout, this, &ObexManagerPrivate::load);
 }
 
 void ObexManagerPrivate::init()
@@ -121,6 +101,8 @@ void ObexManagerPrivate::load()
     m_dbusObjectManager = new DBusObjectManager(Strings::orgBluezObex(), QStringLiteral("/"),
             DBusConnection::orgBluezObex(), this);
 
+    connect(m_dbusObjectManager, &DBusObjectManager::InterfacesAdded,
+            this, &ObexManagerPrivate::interfacesAdded);
     connect(m_dbusObjectManager, &DBusObjectManager::InterfacesRemoved,
             this, &ObexManagerPrivate::interfacesRemoved);
 
@@ -145,10 +127,10 @@ void ObexManagerPrivate::getManagedObjectsFinished(QDBusPendingCallWatcher *watc
         const QString &path = it.key().path();
         const QVariantMapMap &interfaces = it.value();
 
-        if (interfaces.contains(Strings::orgBluezObexClient1())) {
+        if (interfaces.contains(Strings::orgBluezObexSession1())) {
+            addSession(path, interfaces.value(Strings::orgBluezObexSession1()));
+        } else if (interfaces.contains(Strings::orgBluezObexClient1()) && interfaces.contains(Strings::orgBluezObexAgentManager1())) {
             m_obexClient = new ObexClient(Strings::orgBluezObex(), path, DBusConnection::orgBluezObex(), this);
-        }
-        if (interfaces.contains(Strings::orgBluezObexAgentManager1())) {
             m_obexAgentManager = new ObexAgentManager(Strings::orgBluezObex(), path, DBusConnection::orgBluezObex(), this);
         }
     }
@@ -174,19 +156,27 @@ void ObexManagerPrivate::clear()
 {
     m_loaded = false;
 
+    // Delete all sessions
+    while (!m_sessions.isEmpty()) {
+        ObexSessionPtr session = m_sessions.begin().value();
+        m_sessions.remove(m_sessions.begin().key());
+        Q_EMIT q->sessionRemoved(session);
+    }
+
+    // Delete all other objects
     if (m_obexClient) {
         m_obexClient->deleteLater();
-        m_obexClient = Q_NULLPTR;
+        m_obexClient = nullptr;
     }
 
     if (m_obexAgentManager) {
         m_obexAgentManager->deleteLater();
-        m_obexAgentManager = Q_NULLPTR;
+        m_obexAgentManager = nullptr;
     }
 
     if (m_dbusObjectManager) {
         m_dbusObjectManager->deleteLater();
-        m_dbusObjectManager = Q_NULLPTR;
+        m_dbusObjectManager = nullptr;
     }
 }
 
@@ -198,7 +188,7 @@ void ObexManagerPrivate::serviceRegistered()
     // Client1 and AgentManager1 objects are not ready by the time org.bluez.obex is registered
     // nor will the ObjectManager emits interfacesAdded for adding them...
     // So we delay the call to load() by 0.5s
-    m_timer->start();
+    m_timer.start(500);
 }
 
 void ObexManagerPrivate::serviceUnregistered()
@@ -210,13 +200,48 @@ void ObexManagerPrivate::serviceUnregistered()
     Q_EMIT q->operationalChanged(false);
 }
 
+void ObexManagerPrivate::interfacesAdded(const QDBusObjectPath &objectPath, const QVariantMapMap &interfaces)
+{
+    const QString &path = objectPath.path();
+    QVariantMapMap::const_iterator it;
+
+    for (it = interfaces.constBegin(); it != interfaces.constEnd(); ++it) {
+        if (it.key() == Strings::orgBluezObexSession1()) {
+            addSession(path, it.value());
+        }
+    }
+}
+
 void ObexManagerPrivate::interfacesRemoved(const QDBusObjectPath &objectPath, const QStringList &interfaces)
 {
-    if (interfaces.contains(Strings::orgBluezObexSession1())) {
-        Q_EMIT q->sessionRemoved(objectPath);
+    const QString &path = objectPath.path();
+
+    for (const QString &interface : interfaces) {
+        if (interface == Strings::orgBluezObexSession1()) {
+            removeSession(path);
+        }
     }
 }
 
+void ObexManagerPrivate::addSession(const QString &sessionPath, const QVariantMap &properties)
+{
+    ObexSessionPtr session = ObexSessionPtr(new ObexSession(sessionPath, properties));
+    session->d->q = session.toWeakRef();
+    m_sessions.insert(sessionPath, session);
+
+    Q_EMIT q->sessionAdded(session);
+}
+
+void ObexManagerPrivate::removeSession(const QString &sessionPath)
+{
+    ObexSessionPtr session = m_sessions.take(sessionPath);
+    if (!session) {
+        return;
+    }
+
+    Q_EMIT q->sessionRemoved(session);
+}
+
 void ObexManagerPrivate::dummy()
 {
 }
